==> haskell-warp-3.2.13-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.13
id: warp-3.2.13-3b9ahS01zRZ7bE17bwbPRa
key: warp-3.2.13-3b9ahS01zRZ7bE17bwbPRa
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Some
                Network.Wai.Handler.Warp.Timeout Network.Wai.Handler.Warp.Types
                Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
abi: f0b3c93ce56b623a03d1fe3aa59196c4
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/warp-3.2.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/warp-3.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/warp-3.2.13
hs-libraries: HSwarp-3.2.13-3b9ahS01zRZ7bE17bwbPRa
depends:
    array-0.5.1.1 async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy
    auto-update-0.1.4-EmUvNdmhEju51bHrtaEMpz base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw containers-0.5.7.1
    ghc-prim-0.5.0.0 hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    http-date-0.0.6.1-L7XpICKks6SDT9rfFdS3mT
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    http2-1.6.3-G4LhYXcFb4b4klzDEKCGjF
    iproute-1.7.1-EJjAtfniBUorobFQnk7lR
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    simple-sendfile-0.2.25-6OMSpqYXoFV3sBRuDlA99f
    stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
    streaming-commons-0.1.18-KZl1SWhWop6Ksa4IiFWi6P
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq unix-2.7.2.1
    unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
    vault-0.3.0.7-E4lXhyEMoKrEIYQFhBY3rZ
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    word8-0.1.2-9WDPGCTpW7JJnsiAQavtd1
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.2.13-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.13
id: warp-3.2.13-2zIfvy7PaU822kbwwTyJQq
key: warp-3.2.13-2zIfvy7PaU822kbwwTyJQq
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Some
                Network.Wai.Handler.Warp.Timeout Network.Wai.Handler.Warp.Types
                Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
abi: 5bb3cd179edd3e6ff28b56a321d44025
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/warp-3.2.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/warp-3.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/warp-3.2.13
hs-libraries: HSwarp-3.2.13-2zIfvy7PaU822kbwwTyJQq
depends:
    array-0.5.1.1 async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy
    auto-update-0.1.4-EmUvNdmhEju51bHrtaEMpz base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw containers-0.5.7.1
    ghc-prim-0.5.0.0 hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    http-date-0.0.6.1-8J68av0IjJXKU1aAxYlZ6H
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    http2-1.6.3-G4LhYXcFb4b4klzDEKCGjF
    iproute-1.7.1-EJjAtfniBUorobFQnk7lR
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    simple-sendfile-0.2.25-6OMSpqYXoFV3sBRuDlA99f
    stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
    streaming-commons-0.1.18-KZl1SWhWop6Ksa4IiFWi6P
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq unix-2.7.2.1
    unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
    vault-0.3.0.7-E4lXhyEMoKrEIYQFhBY3rZ
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    word8-0.1.3-9o1uWQQ6KysJq8GGsVHHit
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
